# Generated by Django 4.0.4 on 2022-05-20 20:20

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='CustomUrl',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('url', models.CharField(db_index=True, max_length=100, unique=True, verbose_name='Path')),
                ('file', models.FileField(upload_to='custom_url', validators=[django.core.validators.FileExtensionValidator(allowed_extensions=['txt', 'csv', 'doc', 'docx', 'xls', 'xlsx', 'ppt', 'pptx', 'gif', 'jpg', 'jpeg', 'png', 'tif', 'tiff', 'svg', 'pdf'])], verbose_name='File')),
                ('file_type', models.CharField(choices=[('text/plain', 'Plain Text'), ('text/csv', 'CSV'), ('application/vnd.ms-excel', 'MS Excel'), ('application/msword', 'MS Word'), ('application/vnd.ms-powerpoint', 'MS PowerPoint'), ('image/gif', 'GIF'), ('image/jpeg', 'JPEG'), ('image/png', 'PNG'), ('image/tiff', 'TIFF'), ('image/svg+xml', 'SVG'), ('application/pdf', 'PDF')], max_length=50, verbose_name='File Type')),
            ],
        ),
    ]
